Dense Matrices
==============

.. autoclass:: sympy.matrices.dense::Matrix
   :members:

.. autoclass:: sympy.matrices.dense::DenseMatrix
   :members:
.. autoclass:: sympy.matrices.dense::MutableDenseMatrix
   :members:

.. autoclass:: sympy.matrices.immutable::ImmutableDenseMatrix
   :members:
   :noindex:
